@@ -20,7 +20,7 @@ class MostEffectiveContentIG:
     higher engagement rate.
     """
 
-    def __init__(self, df_posts, groups):
+    def __init__(self, df_posts, groups, mode="status"):
         """
         This method computes the DataFrame 'df_posts_full'
         which contains all the information of the posts, including column
@@ -41,60 +41,98 @@ class MostEffectiveContentIG:
 
         METHOD_NAME = "__init__"
 
-        POSTS_COLUMNS = [
-            "owner_id",
-            "owner_username",
-            "shortcode",
-            "caption",
-            "typename",
-            "caption_hashtags",
-            "caption_mentions",
-            "group",
-            "engagement_rate_by_post",
-            "rel_engagement_rate_by_post",
-        ]
-
-        OUTPUT_COLUMNS = [
-            "owner_id",
-            "owner_username",
-            "shortcode",
-            "caption",
-            "typename",
-            "caption_hashtags",
-            "caption_mentions",
-            "group",
-            "engagement_rate_by_post",
-            "rel_engagement_rate_by_post",
-        ]
-
         self.features = None
+        self.mode = mode
 
-        if len(df_posts) > 0:
-            try:
-                df_posts_full = deepcopy(df_posts[POSTS_COLUMNS])
-                df_posts_full["owner_id"] = df_posts_full["owner_id"].apply(
-                    lambda uid: str(uid)
-                )
+        if self.mode == "status":
 
-                df_posts_full["group"] = df_posts_full["owner_id"].apply(
-                    lambda pid: general_utils.get_group(pid, groups)
-                )
+            POSTS_COLUMNS = [
+                "owner_id",
+                "owner_username",
+                "shortcode",
+                "caption",
+                "typename",
+                "caption_hashtags",
+                "caption_mentions",
+                "group",
+                "engagement_rate_by_post",
+                "rel_engagement_rate_by_post",
+            ]
 
-                self.df_posts_full = df_posts_full
-                self.len_posts_full = len(self.df_posts_full)
+            OUTPUT_COLUMNS = [
+                "owner_id",
+                "owner_username",
+                "shortcode",
+                "caption",
+                "typename",
+                "caption_hashtags",
+                "caption_mentions",
+                "group",
+                "engagement_rate_by_post",
+                "rel_engagement_rate_by_post",
+            ]
 
-            except Exception as e:
-                exception_type = sys.exc_info()[0]
-                print(ERR_SYS + str(exception_type))
-                print(e)
-                print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
+            if len(df_posts) > 0:
+                try:
+                    df_posts_full = deepcopy(df_posts[POSTS_COLUMNS])
+                    df_posts_full["owner_id"] = df_posts_full["owner_id"].apply(
+                        lambda uid: str(uid)
+                    )
+
+                    df_posts_full["group"] = df_posts_full["owner_id"].apply(
+                        lambda pid: general_utils.get_group(pid, groups)
+                    )
+
+                    self.df_posts_full = df_posts_full
+                    self.len_posts_full = len(self.df_posts_full)
+
+                except Exception as e:
+                    exception_type = sys.exc_info()[0]
+                    print(ERR_SYS + str(exception_type))
+                    print(e)
+                    print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
+                    self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS)
+                    self.len_posts_full = len(self.df_posts_full)
+
+            else:
+                print("Warning: The DataFrame is empty. It cannot be computed.")
                 self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS)
                 self.len_posts_full = len(self.df_posts_full)
 
-        else:
-            print("Warning: The DataFrame is empty. It cannot be computed.")
-            self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS)
-            self.len_posts_full = len(self.df_posts_full)
+        elif self.mode == "hashtags":
+            HASHTAGS_COLUMNS = [
+                "followers",
+                "group",
+                "likes_count",
+                "comment_count",
+                "typename",
+                "caption",
+                "engagement_rate_by_post",
+            ]
+            OUTPUT_COLUMNS = [
+                "followers",
+                "group",
+                "likes_count",
+                "comment_count",
+                "typename",
+                "caption",
+                "engagement_rate_by_post",
+            ]
+            try:
+                df_posts_full = deepcopy(df_posts[HASHTAGS_COLUMNS])
+                # rel_engagement no tiene sentido en este caso por eso está quemado
+                df_posts_full["rel_engagement_rate_by_post"] = df_posts_full[
+                    "engagement_rate_by_post"
+                ]
+
+                self.df_posts_full = df_posts_full
+                self.len_posts_full = len(self.df_posts_full)
+            except Exception as e:
+                exception_type = sys.exc_info()[0]
+                print(ERR_SYS + str(exception_type))
+                print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
+                self.df_posts_full = pd.DataFrame(columns=OUTPUT_COLUMNS)
+                self.len_posts_full = len(self.df_posts_full)
 
     def posts(self, n_most_eff=5, engagement_rate="engagement_rate_by_post", **kwargs):
         """
