@@ -148,7 +148,9 @@ class MostEffectiveContentTW:
                 f'Mode {mode} is not available. Modes available: "status" and "terms".'
             )
 
-    def posts(self, n_most_eff=5, engagement_rate="engagement_rate_by_post", **kwargs):
+    def posts(
+        self, n_most_eff=None, engagement_rate="engagement_rate_by_post", **kwargs
+    ):
         """
         This function computes the DataFrame 'df_most_eff_posts_tw'
         which contains the posts with higher engagement rate for the accounts selected.
@@ -221,9 +223,14 @@ class MostEffectiveContentTW:
             df_most_eff_posts_tw["url"] = df_most_eff_posts_tw["tweet_id"].apply(
                 lambda x: f"twitter.com/user/status/{x}"
             )
+            if n_most_eff:
+                max_n = min(n_most_eff, len(df_most_eff_posts_tw))
+            else:
+                max_n = min(100, len(df_most_eff_posts_tw))
+
             df_most_eff_posts_tw = df_most_eff_posts_tw.sort_values(
                 engagement_rate, ascending=False
-            ).head(n_most_eff)
+            ).head(max_n)
 
             return df_most_eff_posts_tw
 
